==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_functions/mp1027_001/MP1027_AddInspectionPoint_001.java <==

package net.datastream.schemas.mp_functions.mp1027_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.inspectionpoint_001.InspectionPoint;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/InspectionPoint_001}InspectionPoint"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="InspectionPoint" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirm_duplicatepoint_allowed" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "inspectionPoint"
})
@XmlRootElement(name = "MP1027_AddInspectionPoint_001")
public class MP1027_AddInspectionPoint_001 {

    @XmlElement(name = "InspectionPoint", namespace = "http://schemas.datastream.net/MP_entities/InspectionPoint_001", required = true)
    protected InspectionPoint inspectionPoint;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_duplicatepoint_allowed")
    protected String confirm_Duplicatepoint_Allowed;

    /**
     * Obtient la valeur de la propriété inspectionPoint.
     * 
     * @return
     *     possible object is
     *     {@link InspectionPoint }
     *     
     */
    public InspectionPoint getInspectionPoint() {
        return inspectionPoint;
    }

    /**
     * Définit la valeur de la propriété inspectionPoint.
     * 
     * @param value
     *     allowed object is
     *     {@link InspectionPoint }
     *     
     */
    public void setInspectionPoint(InspectionPoint value) {
        this.inspectionPoint = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.INSPECTION_POINT;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Duplicatepoint_Allowed.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Duplicatepoint_Allowed() {
        if (confirm_Duplicatepoint_Allowed == null) {
            return "not_needed";
        } else {
            return confirm_Duplicatepoint_Allowed;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Duplicatepoint_Allowed.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Duplicatepoint_Allowed(String value) {
        this.confirm_Duplicatepoint_Allowed = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_functions/mp1027_001/MP1027_AddInspectionPoint_001.java <==

package net.datastream.schemas.mp_functions.mp1027_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.inspectionpoint_001.InspectionPoint;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/InspectionPoint_001}InspectionPoint"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="InspectionPoint" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirm_duplicatepoint_allowed" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "inspectionPoint"
})
@XmlRootElement(name = "MP1027_AddInspectionPoint_001")
public class MP1027_AddInspectionPoint_001 {

    @XmlElement(name = "InspectionPoint", namespace = "http://schemas.datastream.net/MP_entities/InspectionPoint_001", required = true)
    protected InspectionPoint inspectionPoint;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_duplicatepoint_allowed")
    protected String confirm_Duplicatepoint_Allowed;

    /**
     * Gets the value of the inspectionPoint property.
     * 
     * @return
     *     possible object is
     *     {@link InspectionPoint }
     *     
     */
    public InspectionPoint getInspectionPoint() {
        return inspectionPoint;
    }

    /**
     * Sets the value of the inspectionPoint property.
     * 
     * @param value
     *     allowed object is
     *     {@link InspectionPoint }
     *     
     */
    public void setInspectionPoint(InspectionPoint value) {
        this.inspectionPoint = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.INSPECTION_POINT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the confirm_Duplicatepoint_Allowed property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Duplicatepoint_Allowed() {
        if (confirm_Duplicatepoint_Allowed == null) {
            return "not_needed";
        } else {
            return confirm_Duplicatepoint_Allowed;
        }
    }

    /**
     * Sets the value of the confirm_Duplicatepoint_Allowed property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Duplicatepoint_Allowed(String value) {
        this.confirm_Duplicatepoint_Allowed = value;
    }

}
